@@ -14,13 +14,11 @@ static PopplerRectangle poppler_rect_from_zathura(zathura_rectangle_t rectangle)
 
 char* pdf_page_get_text(zathura_page_t* page, void* data, zathura_rectangle_t rectangle, zathura_error_t* error) {
   if (page == NULL || data == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
-    }
+    zathura_check_set_error(error, ZATHURA_ERROR_INVALID_ARGUMENTS);
     return NULL;
   }
 
-  PopplerRectangle rect = poppler_rect_from_zathura(rectangle);
+  PopplerRectangle rect     = poppler_rect_from_zathura(rectangle);
   PopplerPage* poppler_page = data;
 
   /* get selected text */
@@ -30,20 +28,16 @@ char* pdf_page_get_text(zathura_page_t* page, void* data, zathura_rectangle_t re
 girara_list_t* pdf_page_get_selection(zathura_page_t* page, void* data, zathura_rectangle_t rectangle,
                                       zathura_error_t* error) {
   if (page == NULL || data == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
-    }
+    zathura_check_set_error(error, ZATHURA_ERROR_INVALID_ARGUMENTS);
     return NULL;
   }
 
-  PopplerRectangle rect = poppler_rect_from_zathura(rectangle);
+  PopplerRectangle rect     = poppler_rect_from_zathura(rectangle);
   PopplerPage* poppler_page = data;
 
-  girara_list_t* list = girara_list_new2(g_free);
+  girara_list_t* list = girara_list_new_with_free(g_free);
   if (list == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_OUT_OF_MEMORY;
-    }
+    zathura_check_set_error(error, ZATHURA_ERROR_OUT_OF_MEMORY);
     goto error_free;
   }
 
@@ -53,11 +47,17 @@ girara_list_t* pdf_page_get_selection(zathura_page_t* page, void* data, zathura_
     cairo_rectangle_int_t r;
     cairo_region_get_rectangle(region, n, &r);
 
-    zathura_rectangle_t* inner_rectangle = g_malloc0(sizeof(zathura_rectangle_t));
-    inner_rectangle->x1                  = r.x;
-    inner_rectangle->x2                  = r.x + r.width;
-    inner_rectangle->y1                  = r.y;
-    inner_rectangle->y2                  = r.y + r.height;
+    zathura_rectangle_t* inner_rectangle = g_try_malloc0(sizeof(zathura_rectangle_t));
+    if (inner_rectangle == NULL) {
+      zathura_check_set_error(error, ZATHURA_ERROR_OUT_OF_MEMORY);
+      cairo_region_destroy(region);
+      goto error_free;
+    }
+
+    inner_rectangle->x1 = r.x;
+    inner_rectangle->x2 = r.x + r.width;
+    inner_rectangle->y1 = r.y;
+    inner_rectangle->y2 = r.y + r.height;
     girara_list_append(list, inner_rectangle);
   }
   cairo_region_destroy(region);
